
var zip = new JSZip();
var generatedCount = getGeneratedCountFromLocalStorage(); // Retrieve the generated count from localStorage
var qrTotalLimit = 15; // Set the total QR code limit
var limitDuration = "minute"; // Set the limit duration (day/hour/minute/second)
var limitDurationValue = 1; // Set the limit duration value (per day/hour/minute/second)
var limit;
var resetInterval;
var lastGeneratedTimestamp = getLastGeneratedTimestampFromLocalStorage(); // Retrieve the last generated timestamp from localStorage

// Determine the limit and reset interval based on the limit duration
if (limitDuration === "day") {
    limit = Math.min(limitDurationValue, qrTotalLimit);
    resetInterval = 24 * 60 * 60 * 1000; // 24 hours
} else if (limitDuration === "hour") {
    limit = Math.min(limitDurationValue, qrTotalLimit);
    resetInterval = 60 * 60 * 1000; // 1 hour
} else if (limitDuration === "minute") {
    limit = Math.min(limitDurationValue, qrTotalLimit);
    resetInterval = 60 * 1000; // 1 minute
} else if (limitDuration === "second") {
    limit = Math.min(limitDurationValue, qrTotalLimit);
    resetInterval = 1000; // 1 second
}

// Reset the generated count if the specified time interval has passed since the last generation
var currentTimestamp = new Date().getTime();
var timeDiff = currentTimestamp - lastGeneratedTimestamp;
if (timeDiff >= resetInterval) {
    generatedCount = 0; // Reset the generated count
    setGeneratedCountToLocalStorage(generatedCount);
    setLastGeneratedTimestampToLocalStorage(currentTimestamp);
}

// Check if the IP address has exceeded the limit
var ipAddress = "<?php echo $_SERVER['REMOTE_ADDR']; ?>";
if (hasExceededLimit(ipAddress)) {
    disableGeneration();
    showLimitExceededMessage();
}

function generateQR() {
    var data = document.getElementById("data").value;
    var dataLines = data.split("\n");
    var size = parseInt(document.getElementById("size").value);

    var qrcodesDiv = document.getElementById("qrcodes");
    qrcodesDiv.innerHTML = "";

    var colsPerLine;
    if (size === 90) {
        colsPerLine = 8;
    } else if (size === 150) {
        colsPerLine = 5;
    } else if (size === 250) {
        colsPerLine = 3;
    } else if (size === 500) {
        colsPerLine = 2;
    }

    var remainingCount = Math.max(qrTotalLimit - generatedCount, 0); // Handle negative count
    var count = Math.min(dataLines.length, remainingCount);

    for (var i = 0; i < count; i++) {
        var qrDiv = document.createElement("div");
        qrDiv.className = "col mb-3";
        qrDiv.style.width = size + "px";
        qrDiv.style.height = size + "px";
        var qrCode = new QRCode(qrDiv, {
            text: dataLines[i],
            width: size,
            height: size,
        });
        qrcodesDiv.appendChild(qrDiv);

        var qrCodeData = qrCode._el.querySelector("canvas").toDataURL("image/png");
        var fileName = "qrcode_" + i + ".png";
        var base64Data = qrCodeData.split(",")[1];
        zip.file(fileName, base64Data, { base64: true });

        generatedCount++;
    }

    remainingCount = Math.max(qrTotalLimit - generatedCount, 0); // Handle negative count
    updateQRCodeAvailability(remainingCount);

    if (remainingCount <= 0) {
        disableGeneration();
        showLimitExceededMessage();
    }

    var downloadContainer = document.getElementById("downloadContainer");
    downloadContainer.innerHTML = "";

    var downloadButton = document.createElement("button");
    downloadButton.className = "btn btn-primary";
    downloadButton.textContent = "Download All";
    downloadButton.addEventListener("click", downloadAll);
    downloadContainer.appendChild(downloadButton);

    downloadContainer.style.display = "block";

    // Store the updated generated count in localStorage
    setGeneratedCountToLocalStorage(generatedCount);

    // Update the line count
    updateLineCount();

    // Update the last generated timestamp to the current timestamp
    lastGeneratedTimestamp = new Date().getTime();
    setLastGeneratedTimestampToLocalStorage(lastGeneratedTimestamp);
}

function disableGeneration() {
    var remainingCount = Math.max(qrTotalLimit - generatedCount, 0); // Handle negative count
    if (remainingCount <= 0) {
        document.getElementById("generateButton").disabled = true;
        document.getElementById("size").disabled = true; // Disable the size dropdown
    }
}

function showLimitExceededMessage() {
    var remainingCount = Math.max(qrTotalLimit - generatedCount, 0); // Calculate remaining count

    var messageContainer = document.getElementById("messageContainer");
    messageContainer.innerHTML = "";

    var messageText = document.createElement("div");

    if (remainingCount > 0) {
        messageText.textContent = "You have an available limit of " + remainingCount + " QR codes.";
    } else {
        messageText.textContent = "QR code generation limit exceeded for this interval.";

        var timerElement = document.createElement("div");
        timerElement.id = "timer";
        messageContainer.appendChild(timerElement);

        var lastGeneratedTimestamp = getLastGeneratedTimestampFromLocalStorage();
        var endTime = new Date(lastGeneratedTimestamp + resetInterval);
        startTimer(endTime, timerElement);
    }

    messageContainer.appendChild(messageText);
    messageContainer.style.display = "block";
}


function updateQRCodeAvailability(remainingCount) {
    var qrCodeAvailabilityElement = document.getElementById("qrCodeAvailability");
    qrCodeAvailabilityElement.innerHTML = "Remaining Limit: " + remainingCount;
}

function downloadAll() {
    zip.generateAsync({ type: "blob" }).then(function (content) {
        saveAs(content, "qrcodes.zip");
    });
}

function getGeneratedCountFromLocalStorage() {
    var count = localStorage.getItem("qrcode_generated_count");
    return count ? parseInt(count) : 0;
}

function setGeneratedCountToLocalStorage(count) {
    localStorage.setItem("qrcode_generated_count", count);
}

function updateLineCount() {
    var data = document.getElementById("data").value;
    var lines = data.split("\n");
    var nonEmptyLines = lines.filter(line => line.trim() !== "");
    var lineCount = nonEmptyLines.length;
    var lineCountElement = document.getElementById("lineCount");
    lineCountElement.textContent = lineCount + " lines entered";
}

function getLastGeneratedTimestampFromLocalStorage() {
    var timestamp = localStorage.getItem("last_generated_timestamp");
    return timestamp ? parseInt(timestamp) : 0;
}

function setLastGeneratedTimestampToLocalStorage(timestamp) {
    localStorage.setItem("last_generated_timestamp", timestamp);
}

function getResetTime() {
    var currentDate = new Date();
    var resetDate = new Date(currentDate.getTime() + resetInterval);
    var timeDiff = resetDate - currentDate;

    var hours = Math.floor(timeDiff / (1000 * 60 * 60));
    var minutes = Math.floor((timeDiff % (1000 * 60 * 60)) / (1000 * 60));
    var seconds = Math.floor((timeDiff % (1000 * 60)) / 1000);

    var resetTime = "";
    if (hours > 0) {
        resetTime += hours + " hours ";
    }
    if (minutes > 0) {
        resetTime += minutes + " minutes ";
    }
    if (seconds > 0) {
        resetTime += seconds + " seconds";
    }

    return resetTime;
}

function startTimer(endTime, timerElement) {
    var timer = setInterval(function() {
        var now = new Date().getTime();
        var timeDiff = endTime - now;

        var hours = Math.floor(timeDiff / (1000 * 60 * 60));
        var minutes = Math.floor((timeDiff % (1000 * 60 * 60)) / (1000 * 60));
        var seconds = Math.floor((timeDiff % (1000 * 60)) / 1000);

        var timerText = "";
        if (hours > 0) {
            timerText += hours + " hours ";
        }
        if (minutes > 0) {
            timerText += minutes + " minutes ";
        }
        if (seconds > 0) {
            timerText += seconds + " seconds";
        }

        timerElement.textContent = "Limit will be reset in " + timerText;

        if (timeDiff <= 0) {
            clearInterval(timer);
        }
    }, 1000);
}

// Generate a UUID if not already present in localStorage
var uuid = localStorage.getItem("qrcode_uuid");
if (!uuid) {
    uuid = generateUUID();
    localStorage.setItem("qrcode_uuid", uuid);
}

// Get the unique identifier from cookies
function getUniqueIdentifier() {
    return getCookie("qrcode_uuid");
}

// Check if the unique identifier has exceeded the limit
function hasExceededLimit() {
    var uniqueIdentifier = getUniqueIdentifier();
    var count = getCookie("qrcode_generated_count_" + uniqueIdentifier);
    return count ? parseInt(count) >= qrTotalLimit : false;
}

// Increment the count for the unique identifier
function incrementCount() {
    var uniqueIdentifier = getUniqueIdentifier();
    var count = getCookie("qrcode_generated_count_" + uniqueIdentifier);
    count = count ? parseInt(count) + 1 : 1;
    setCookie("qrcode_generated_count_" + uniqueIdentifier, count);
}

// Generate a UUID
function generateUUID() {
    var d = new Date().getTime();
    if (typeof performance !== "undefined" && typeof performance.now === "function") {
        d += performance.now(); // use high-precision timer if available
    }
    return "xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g, function (c) {
        var r = (d + Math.random() * 16) % 16 | 0;
        d = Math.floor(d / 16);
        return (c === "x" ? r : (r & 0x3) | 0x8).toString(16);
    });
}

// Get the value of a cookie by name
function getCookie(name) {
    var cookies = document.cookie.split(';');
    for (var i = 0; i < cookies.length; i++) {
        var cookie = cookies[i].trim();
        if (cookie.startsWith(name + '=')) {
            return cookie.substring(name.length + 1);
        }
    }
    return '';
}

// Set the value of a cookie
function setCookie(name, value) {
    document.cookie = name + '=' + value + ';path=/';
}

if (hasExceededLimit()) {
    disableGeneration();
    showLimitExceededMessage();
}

document.getElementById("messageContainer").style.display = "block";
updateLineCount(); // Initial line count
updateQRCodeAvailability(Math.max(qrTotalLimit - generatedCount, 0)); // Initial QR code availability

