
    // Words related to different business categories
    const categoryWords = {
      tech: [
        'tech', 'web', 'code', 'cloud', 'smart', 'app', 'net', 'data', 'connect', 'digital',
        'cyber', 'byte', 'robot', 'virtual', 'techy', 'codez', 'ninja', 'geek', 'webz', 'dataz',
        'innov', 'e-sol', 'logic', 'cyberx', 'bytes', 'hyper',
      ],
      finance: [
        'finance', 'money', 'fund', 'invest', 'capital', 'pay', 'coin', 'wealth', 'cash',
        'bank', 'fundz', 'payday', 'dollars', 'profit', 'coins', 'vault', 'capitalz', 'bucks',
        'gold', 'econo', 'investz', 'assets', 'cents', 'banker', 'wealthy', 'rich',
      ],
      health: [
        'health', 'fit', 'wellness', 'med', 'care', 'life', 'body', 'heal', 'clinic',
        'healthy', 'vital', 'wellz', 'lifex', 'medico', 'wellwise', 'carez', 'healthful', 'healer',
        'well-being', 'bodyz', 'healing', 'medix', 'fitn', 'vitality', 'lifeplus', 'careful',
      ],
      food: [
        'food', 'eat', 'tasty', 'yum', 'delicious', 'dine', 'meal', 'fresh', 'chef',
        'cuisine', 'yummy', 'tastez', 'eatz', 'deliz', 'gourmet', 'cater', 'grub', 'culin', 'yumz',
        'bistro', 'feed', 'taster', 'flavor', 'gourm', 'kitch', 'munch', 'palate', 'crave',
      ],
      travel: [
        'travel', 'trip', 'explore', 'wander', 'journey', 'adventure', 'vacation', 'roam',
        'voyage', 'trav', 'wanderz', 'advent', 'tripper', 'journez', 'tourz', 'wanderer', 'jetset',
        'exped', 'venture', 'sojourn', 'tourist', 'globetrot', 'rambl', 'trek', 'voyagez', 'pathfind',
      ],
      fashion: [
        'fashion', 'style', 'trend', 'wear', 'dress', 'clothes', 'design', 'couture',
        'moda', 'trendy', 'stylish', 'fashionz', 'dazzle', 'glam', 'designer', 'chic', 'trendz',
        'garb', 'vogue', 'apparel', 'couturier', 'attire', 'dressy', 'outfit', 'stylez', 'trendset',
        'ensemble', 'wearable', 'fab', 'catwalk', 'wardrobe',
      ],
      // Add more categories and related words as needed
    };

    function populateCategories() {
      const categorySelect = document.getElementById('categorySelect');

      for (const category in categoryWords) {
        const option = document.createElement('option');
        option.value = category;
        option.textContent = category.charAt(0).toUpperCase() + category.slice(1);
        categorySelect.appendChild(option);
      }

      // Add an option for user-entered keyword
      const optionUserKeyword = document.createElement('option');
      optionUserKeyword.value = 'userKeyword';
      optionUserKeyword.textContent = 'User-Entered Keyword';
      categorySelect.appendChild(optionUserKeyword);
    }

    function getRandomWord(words) {
      const randomIndex = Math.floor(Math.random() * words.length);
      return words[randomIndex];
    }

    function checkDomainAvailability(domain, callback) {
      const xhr = new XMLHttpRequest();
      xhr.onreadystatechange = function () {
        if (xhr.readyState === 4 && xhr.status === 200) {
          const isAvailable = xhr.responseText === 'true';
          callback(isAvailable);
        }
      };
      xhr.open('GET', `class/domain_check.php?domain=${domain}`, true);
      xhr.send();
    }

    function generateDomainNames() {
      const selectedCategory = document.getElementById('categorySelect').value;
      const relatedWords = selectedCategory === 'userKeyword' ? [] : categoryWords[selectedCategory];

      const keyword = document.getElementById('keywordInput').value.trim();
      if (!keyword && selectedCategory === 'userKeyword') {
        alert('Please enter a keyword.');
        return;
      }

      const domainResults = [];
      for (let i = 0; i < 10; i++) {
        const word1 = relatedWords.length ? getRandomWord(relatedWords) : '';
        const word2 = relatedWords.length ? getRandomWord(relatedWords) : '';
        const domainName = relatedWords.length ? `${keyword}${word1}${word2}` : `${keyword}`;
        domainResults.push(domainName);
      }

      const domainResultElement = document.getElementById('domainResult');
      domainResultElement.innerHTML = ''; // Clear previous results

      const progressBar = document.getElementById('progressBar');
      const progressBarContainer = document.getElementById('progressBarContainer');
      const loader = document.getElementById('loader');

      progressBar.style.width = '0%';
      progressBarContainer.style.display = 'block';
      loader.style.display = 'block';

      const totalDomains = domainResults.length;
      let processedDomains = 0;

    // Get the selected domain extensions
      const domainSelectElement = document.getElementById('domainSelect');
      const domainExtensions = Array.from(domainSelectElement.querySelectorAll('input[type="checkbox"]'))
        .filter((checkbox) => checkbox.checked)
        .map((checkbox) => checkbox.value);

      domainResults.forEach((domain) => {
        // Check domain availability for each selected domain extension
        domainExtensions.forEach((extension) => {
          const fullDomain = domain + extension;
          checkDomainAvailability(fullDomain, (isAvailable) => {
            const listItem = document.createElement('li');
            listItem.className = 'domain-item';
            listItem.innerHTML = `
              <span>${fullDomain}</span>
              <span class="domain-availability ${isAvailable ? 'available' : 'not-available'}">${isAvailable ? 'Available' : 'Not Available'}</span>

              
             <a href="${isAvailable ? getRegisterURL(fullDomain) : getWhoisURL(fullDomain)}" target="_blank" class="${isAvailable ? 'register-btn' : 'whois-btn'}">${isAvailable ? 'Register' : 'Whois'}</a>

            `;
            domainResultElement.appendChild(listItem);

            processedDomains++;
            const progressPercentage = (processedDomains / (totalDomains * domainExtensions.length)) * 100;
            progressBar.style.width = `${progressPercentage}%`;

            if (processedDomains === totalDomains * domainExtensions.length) {
              progressBarContainer.style.display = 'none';
              loader.style.display = 'none';
            }
          });
        });
      });
    }
    function getWhoisURL(domain) {
      return `https://in.godaddy.com/whois/results.aspx?domainName=${domain}`;
    }

    function getRegisterURL(domain) {
      return `https://www.godaddy.com/en-in/domainsearch/find?domainToCheck=${domain}`;
      // Replace 'example.com' with the actual URL of the domain registration service.
    }

    // Populate the categories when the page loads
    populateCategories();
